/*
Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'docprops', 'ja', {
	bgColor: '背景色',
	bgFixed: 'スクロールしない背景',
	bgImage: '背景画像 URL',
	charset: '文字コード',
	charsetASCII: 'ASCII',
	charsetCE: 'Central European',
	charsetCR: 'Cyrillic',
	charsetCT: 'Chinese Traditional (Big5)',
	charsetGR: 'ギリシャ語',
	charsetJP: '日本語',
	charsetKR: '韓国語',
	charsetOther: '他の文字セット符号化',
	charsetTR: 'トルコ語',
	charsetUN: 'Unicode (UTF-8)',
	charsetWE: '西欧',
	chooseColor: '色の選択',
	design: 'デザイン',
	docTitle: 'ページタイトル',
	docType: '文書タイプヘッダー',
	docTypeOther: 'その他文書タイプヘッダー',
	label: '文書 プロパティ',
	margin: 'ページ・マージン',
	marginBottom: '下部',
	marginLeft: '左',
	marginRight: '右',
	marginTop: '上部',
	meta: 'メタデータ',
	metaAuthor: '文書の作者',
	metaCopyright: '文書の著作権',
	metaDescription: '文書の概要',
	metaKeywords: '文書のキーワード(カンマ区切り)',
	other: '<その他の>',
	previewHtml: '<p>これは<strong>テキストサンプル</strong>です。 あなたは、<a href="javascript:void(0)">CKEditor</a>を使っています。</p>',
	title: '文書 プロパティ',
	txtColor: 'テキスト色',
	xhtmlDec: 'XHTML宣言をインクルード'
} );
